function createfigure(x1, ymatrix1, x2, ymatrix2)
%CREATEFIGURE(X1,YMATRIX1,X2,YMATRIX2)
%  X1:  vector of x data
%  YMATRIX1:  matrix of y data
%  X2:  vector of x data
%  YMATRIX2:  matrix of y data
 
%  Auto-generated by MATLAB on 04-Oct-2006 10:35:23
 
% Create figure
figure1 = figure('FileName','X:\900225. MARS PROJECT\Project.Documents\02.System.Engineering\Test Results\Filled testing, August 2006\drySideAM.fig','PaperPosition',[-1.052 3.345 10.6 4.319]);
 
% Create axes
axes1 = axes(...
  'XGrid','on',...
  'YGrid','on',...
  'YTick',[20 22 24 26 28 30 32 34 36 38 40 42 44 45 45],...
  'Parent',figure1);
box('on');
hold('all');
 
% Create multiple lines using matrix input to plot
plot1 = plot(x1,ymatrix1);
set(plot1(1),'Color',[0.6824 0.4667 0]);
set(plot1(2),'Color',[0.04314 0.5176 0.7804]);
set(plot1(3),'Color',[1 0 0]);
set(plot1(4),'Color',[0.749 0 0.749]);
set(plot1(6),'Color',[0.8706 0.4902 0]);
 
% Create multiple lines using matrix input to plot
plot2 = plot(x2,ymatrix2);
 
% Create xlabel
xlabel('Time (sec)');
 
% Create ylabel
ylabel('Temperature (degC)');
 
% Create title
title('Aug 17, 2006 AM Dry side temp vs. time in LV housing');
 
% Create legend
legend1 = legend(axes1,{'NE East Chassis','NE East Chassis fit','W EDFA','W EDFA fit','E EDFA','E EDFA fit','NE W Chassis','NE W Chassis fit','Top','Top fit','Bottom','Bottom fit'},'Position',[0.8149 0.4144 0.1664 0.5096]);
 
